@@ -199,7 +199,9 @@ class Parameter(object):
                 settings = {}
 
             common_args = {'size': settings.get('sample_size', 1),
-                           'sample_mean_value': settings.get('sample_mean_value', False)}
+                           'sample_mean_value': settings.get('sample_mean_value', False),
+                           'with_pint_units': settings.get('with_pint_units', False)
+                           }
             common_args.update(**self.kwargs)
 
             if settings.get('use_time_series', False):
@@ -229,11 +231,13 @@ class GrowthTimeSeriesGenerator(DistributionFunctionGenerator):
     # error function growth rate
     ef_growth_factor: str
 
-    def __init__(self, times=None, size=None, index_names=None, ref_date=None, *args, **kwargs):
+    def __init__(self, times=None, size=None, index_names=None, ref_date=None, with_pint_units=False, *args, **kwargs):
         super().__init__(*args, **kwargs)
 
         self.ref_date = ref_date if ref_date else None
-
+        self.with_pint_units = with_pint_units
+        if self.with_pint_units:
+            import pint
         self.times = times
         self.size = size
         iterables = [times, range(0, size)]
@@ -299,16 +303,26 @@ class GrowthTimeSeriesGenerator(DistributionFunctionGenerator):
         # logger.debug(sigma.size)
         # logger.debug(alpha_sigma.shape)
         # logger.debug(months)
-        unit_ = kwargs["unit"]
-        if not unit_:
-            unit_ = 'dimensionless'
+        if self.with_pint_units:
+            unit_ = kwargs["unit"]
+            if not unit_:
+                unit_ = 'dimensionless'
+            dtype = f'pint[{unit_}]'
+        else:
+            dtype = 'float64'
 
         series = pd.Series(((sigma * alpha_sigma) + mu.reshape(months, 1)).ravel(), index=_multi_index,
-                           dtype=f'pint[{unit_}]')
+                           dtype=dtype)
 
         # test if df has sub-zero values
         df_sigma__dropna = series.where(series < 0).dropna()
-        if not df_sigma__dropna.pint.m.empty:
+
+        if self.with_pint_units:
+            _values = df_sigma__dropna.pint.m
+        else:
+            _values = df_sigma__dropna
+
+        if not _values.empty:
             logger.warning(f"Negative values for parameter {name} from {df_sigma__dropna.index[0][0]}")
 
         return series
@@ -345,12 +359,15 @@ class ConstantUncertaintyExponentialGrowthTimeSeriesGenerator(DistributionFuncti
     cagr: str
     ref_date: str
 
-    def __init__(self, cagr=None, times=None, size=None, index_names=None, ref_date=None, *args, **kwargs):
+    def __init__(self, cagr=None, times=None, size=None, index_names=None, ref_date=None, with_pint_units=False, *args,
+                 **kwargs):
         super().__init__(*args, **kwargs)
         self.cagr = cagr if cagr else 0
 
         self.ref_date = ref_date if ref_date else None
-
+        self.with_pint_units = with_pint_units
+        if self.with_pint_units:
+            import pint
         self.times = times
         self.size = size
         iterables = [times, range(0, size)]
@@ -386,11 +403,15 @@ class ConstantUncertaintyExponentialGrowthTimeSeriesGenerator(DistributionFuncti
         # data_series._metadata = kwargs
         # data_series.index.rename(['time', 'samples'], inplace=True)
         #
-        if not kwargs["unit"]:
-            series = pd.Series(values, index=self._multi_index, dtype='pint[dimensionless]')
+        if self.with_pint_units:
+            if not kwargs["unit"]:
+                dtype = 'pint[dimensionless]'
+            else:
+                dtype = f'pint[{kwargs["unit"]}]'
         else:
-            series = pd.Series(values, index=self._multi_index, dtype=f'pint[{kwargs["unit"]}]')
+            dtype = 'float64'
 
+        series = pd.Series(values, index=self._multi_index, dtype=dtype)
         return series
 
 
@@ -606,7 +627,7 @@ class ParameterRepository(object):
             return self.parameter_sets[param].scenarios.keys()
 
 
-class ExcelHandler(object):
+class TableHandler(object):
     version: int
 
     def __init__(self, version=2):
@@ -617,7 +638,7 @@ class ExcelHandler(object):
         raise NotImplementedError()
 
 
-class OpenpyxlExcelHandler(ExcelHandler):
+class OpenpyxlTableHandler(TableHandler):
     def load_definitions(self, sheet_name, filename=None):
         definitions = []
 
@@ -640,7 +661,7 @@ class OpenpyxlExcelHandler(ExcelHandler):
         return definitions
 
 
-class Xlsx2CsvHandler(ExcelHandler):
+class Xlsx2CsvHandler(TableHandler):
     def load_definitions(self, sheet_name, filename=None):
         from xlsx2csv import Xlsx2csv
         data = Xlsx2csv(filename, inmemory=True).convert(None, sheetid=0)
@@ -664,7 +685,7 @@ class Xlsx2CsvHandler(ExcelHandler):
         return definitions
 
 
-class CSVHandler(ExcelHandler):
+class CSVHandler(TableHandler):
     def load_definitions(self, sheet_name, filename=None):
         reader = csv.DictReader(open(filename), delimiter=',')
 
@@ -719,7 +740,7 @@ class CSVHandler(ExcelHandler):
         return definitions
 
 
-class PandasCSVHandler(ExcelHandler):
+class PandasCSVHandler(TableHandler):
 
     def load_definitions(self, sheet_name, filename=None):
         self.version = 2
@@ -736,7 +757,7 @@ class PandasCSVHandler(ExcelHandler):
         return df.to_dict(orient='records')
 
 
-class XLRDExcelHandler(ExcelHandler):
+class XLRDTableHandler(TableHandler):
     version: int
 
     @staticmethod
@@ -747,6 +768,48 @@ class XLRDExcelHandler(ExcelHandler):
         rows = list(sheet.get_rows())
         return len(rows)
 
+    def find_highest_id(self):
+        """
+        stub for id management
+        :return:
+        :rtype:
+        """
+        pass
+
+    def table_visitor(self, wb, _sheet_names, function):
+        """
+        stub for id management
+
+        :param wb:
+        :type wb:
+        :param _sheet_names:
+        :type _sheet_names:
+        :param function:
+        :type function:
+        :return:
+        :rtype:
+        """
+
+        for _sheet_name in _sheet_names:
+            if _sheet_name == 'metadata':
+                continue
+            sheet = wb.sheet_by_name(_sheet_name)
+            rows = list(sheet.get_rows())
+            header = [cell.value for cell in rows[0]]
+
+            if header[0] != 'variable':
+                continue
+
+            for i, row in enumerate(rows[1:]):
+                values = {}
+                for key, cell in zip(header, row):
+                    values[key] = cell.value
+                if not values['variable']:
+                    # logger.debug(f'ignoring row {i}: {row}')
+                    continue
+
+                function()
+
     def load_definitions(self, sheet_name, filename=None):
         import xlrd
         wb = xlrd.open_workbook(filename)
@@ -817,7 +880,7 @@ class XLRDExcelHandler(ExcelHandler):
         return definitions
 
 
-class XLWingsExcelHandler(ExcelHandler):
+class XLWingsTableHandler(TableHandler):
     def load_definitions(self, sheet_name, filename=None):
         import xlwings as xw
         definitions = []
@@ -833,7 +896,7 @@ class XLWingsExcelHandler(ExcelHandler):
             if header[0] != 'variable':
                 continue
 
-            total_rows = XLRDExcelHandler.get_sheet_range_bounds(filename, _sheet_name)
+            total_rows = XLRDTableHandler.get_sheet_range_bounds(filename, _sheet_name)
             range = sheet.range((1, 1), (total_rows, len(header)))
             rows = range.rows
             for row in rows[1:]:
@@ -844,7 +907,7 @@ class XLWingsExcelHandler(ExcelHandler):
         return definitions
 
 
-class ExcelParameterLoader(object):
+class TableParameterLoader(object):
     definition_version: int
     """Utility to populate ParameterRepository from spreadsheets.
 
@@ -858,26 +921,26 @@ class ExcelParameterLoader(object):
 
        """
 
-    def __init__(self, filename, excel_handler='xlrd', version=2, **kwargs):
+    def __init__(self, filename, table_handler='xlrd', version=2, **kwargs):
         self.filename = filename
         self.definition_version = 2  # default - will be overwritten by handler
 
-        logger.info(f'Using {excel_handler} excel handler')
-        excel_handler_instance = None
-        if excel_handler == 'csv':
-            excel_handler_instance = CSVHandler(version)
-        if excel_handler == 'pandas':
-            excel_handler_instance = PandasCSVHandler(version)
-        if excel_handler == 'openpyxl':
-            excel_handler_instance = OpenpyxlExcelHandler()
-        if excel_handler == 'xlsx2csv':
-            excel_handler_instance = Xlsx2CsvHandler()
-        if excel_handler == 'xlwings':
-            excel_handler_instance = XLWingsExcelHandler()
-        if excel_handler == 'xlrd':
-            excel_handler_instance = XLRDExcelHandler()
+        logger.info(f'Using {table_handler} excel handler')
+        table_handler_instance = None
+        if table_handler == 'csv':
+            table_handler_instance = CSVHandler(version)
+        if table_handler == 'pandas':
+            table_handler_instance = PandasCSVHandler(version)
+        if table_handler == 'openpyxl':
+            table_handler_instance = OpenpyxlTableHandler()
+        if table_handler == 'xlsx2csv':
+            table_handler_instance = Xlsx2CsvHandler()
+        if table_handler == 'xlwings':
+            table_handler_instance = XLWingsTableHandler()
+        if table_handler == 'xlrd':
+            table_handler_instance = XLRDTableHandler()
 
-        self.excel_handler: ExcelHandler = excel_handler_instance
+        self.table_handler: TableHandler = table_handler_instance
 
     def load_parameter_definitions(self, sheet_name: str = None):
         """
@@ -902,8 +965,8 @@ class ExcelParameterLoader(object):
         :param sheet_name:
         :return: list of dicts with {header col name : cell value} pairs
         """
-        definitions = self.excel_handler.load_definitions(sheet_name, filename=self.filename)
-        self.definition_version = self.excel_handler.version
+        definitions = self.table_handler.load_definitions(sheet_name, filename=self.filename)
+        self.definition_version = self.table_handler.version
         return definitions
 
     def load_into_repo(self, repository: ParameterRepository = None, sheet_name: str = None):
